pub enum JsonErrorKind {
Syntax,
Data,
EndOfInput,
Io,
}Expand description
JSON parser failure category without response values or parser error prose.
Variants
Syntax
JSON grammar or encoding is invalid.
Data
The JSON shape does not match the envelope, including duplicate fields.
EndOfInput
The input ends before the JSON value is complete.
Io
The underlying JSON parser reported an I/O failure.